
#include "properties/SelfCommuting.hh"

using namespace cadabra;

std::string SelfCommuting::name() const
	{
	return "SelfCommuting";
	}

int SelfCommuting::sign() const
	{
	return 1;
	}
